toot - Mastodon CLI client
==========================

![Toot trumpet logo](./trumpet.png)

Toot is a CLI and TUI tool for interacting with Mastodon (and other compatible) instances from the command line.

[![](https://img.shields.io/badge/author-%40ihabunek-blue.svg?maxAge=3600&style=flat-square)](https://mastodon.social/@ihabunek)
[![](https://img.shields.io/github/license/ihabunek/toot.svg?maxAge=3600&style=flat-square)](https://opensource.org/licenses/GPL-3.0)
[![](https://img.shields.io/pypi/v/toot.svg?maxAge=3600&style=flat-square)](https://pypi.python.org/pypi/toot)

Resources
---------

* [Documentation](https://toot.bezdomni.net/)
* [Source code on GitHub](https://github.com/ihabunek/toot)
* [Issues on GitHub](https://github.com/ihabunek/toot/issues)
* [Mailing list on Sourcehut](https://lists.sr.ht/~ihabunek/toot-discuss) for discussion, support and patches
* Informal discussion on the #toot IRC channel on [libera.chat](https://libera.chat/)

Command line client
-------------------

* Posting, replying, deleting, favouriting, reblogging & pinning statuses
* Support for media uploads, spoiler text, sensitive content
* Search by account or hash tag
* Following, muting and blocking accounts
* Simple switching between multiple Mastodon accounts

Terminal User Interface
-----------------------

toot includes a terminal user interface. Run it with `toot tui`.

![](images/tui_list.png)

![](images/tui_poll.png)

![](images/tui_compose.png)

License
-------

Copyright Ivan Habunek <ivan@habunek.com> and contributors.

Licensed under the [GPLv3](http://www.gnu.org/licenses/gpl-3.0.html) license.
